==> tgpirobot-0.2.5.tar.gz: tgpirobot-0.2.5/README.md <==
# 🤖 TGPIROBOT - Telegram Auto Reply Bot

<p align="center">
  <img src="https://raw.githubusercontent.com/hk4crprasad/hk4crprasad/master/OIG%20(1)_bgremoval.ai.png">
</p>

##
[![Typing SVG](https://readme-typing-svg.demolab.com?font=Robot&size=21&pause=1000&color=C84717&center=true&vCenter=true&random=false&width=435&lines=TGPIROBOT+;Made+by+Hk4crprasad+;pip+install+tgpirobot+)](https://github.com/hk4crprasad)
##
<p align="center">
  <a href="https://github.com/hk4crprasad/tgpirobot">
    <img src="https://img.shields.io/github/stars/hk4crprasad/tgpirobot?style=for-the-badge&color=ee6712"> 
  </a>
  <a href="https://pypi.org/project/tgpirobot">
    <img src="https://img.shields.io/pypi/v/tgpirobot?style=for-the-badge&color=11b8cc">
  </a>
</p>

tgpirobot is a Python library that allows you to auto-reply to messages on Telegram when you are offline!

##
## 🚀 Features

- Send automatic replies when offline ✔️
- Block spammers who send too many messages ❌️  
- Reply with jokes, quotes to engage users 🃏
- Get notifications when someone messages you 📨
- Customize replies easily!

<br>
  
<p align="center">
  <img src="https://raw.githubusercontent.com/hk4crprasad/tgpirobot/master/IMG_20231118_231056.jpg">
</p>

<p align="center"> 
  <b>Demo of tgpirobot auto-replying on Telegram</b>
</p>

##
## 📥 Installation

```bash
pip install tgpirobot
```

```bash
git clone https://github.com/hk4crprasad/tgpirobot.git
cd tgpirobot/tgpirobot
python main.py -r
```
## Update
```bash
pip install --upgrade pirobot
```
<br>

### OR
```bash
python main.py --update
```
##
## 🤹 Usage

### Get API Credentials

- Visit [my.telegram.org](https://my.telegram.org) and login  
- Go to API Development tools
- Create a new app
- Copy `api_id` and `api_hash`

### Run the Bot

```python
Your API_ID: YOUR_API_ID
Your API_HASH: YOUR_API_HASH
Debug mode (true/false): true or false(false is good)
Handler name(Telegram/insta/github) : github
Link : https://github.com/hk4crprasad
```

Now your account will auto-reply when offline! 🎉

### Its ask for Number and Otp

<p align="center">
  <img src="https://raw.githubusercontent.com/hk4crprasad/tgpirobot/master/TGPIROBOT%20(2).png">
</p>

## Also can be used like `from tgpirobot import TgPiRobot`

<p align="center">
  
[![HK4CRPRASAD](https://raw.githubusercontent.com/hk4crprasad/tgpirobot/master/You%20can%20use%20in%20your%20code%20like.svg)](https://github.com/hk4crprasad)

</p>

##
## 🧑 Author 

Made with ❤️ by [hk4crprasad](https://github.com/hk4crprasad)

## 📄 License

[GPL-3.0](https://github.com/hk4crprasad/tgpirobot/blob/master/LICENSE)

<p align="center">
<a href="https://github.com/hk4crprasad/tgpirobot"><img src="https://raw.githubusercontent.com/hk4crprasad/hk4crprasad/master/OIG_bgremoval.ai.png"></a>

==> tgpirobot-0.3.0.tar.gz: tgpirobot-0.3.0/README.md <==
# 🤖 TGPIROBOT - Telegram Auto Reply Bot

<p align="center">
  <img src="https://raw.githubusercontent.com/hk4crprasad/hk4crprasad/master/OIG%20(1)_bgremoval.ai.png">
</p>

##
[![Typing SVG](https://readme-typing-svg.demolab.com?font=Robot&size=21&pause=1000&color=C84717&center=true&vCenter=true&random=false&width=435&lines=TGPIROBOT+;Made+by+Hk4crprasad+;pip+install+tgpirobot+)](https://git.io/typing-svg)
##
<p align="center">
  <a href="https://github.com/hk4crprasad/tgpirobot">
    <img src="https://img.shields.io/github/stars/hk4crprasad/tgpirobot?style=for-the-badge&color=ee6712"> 
  </a>
  <a href="https://pypi.org/project/tgpirobot">
    <img src="https://img.shields.io/pypi/v/tgpirobot?style=for-the-badge&color=11b8cc">
  </a>
</p>

tgpirobot is a Python library that allows you to auto-reply to messages on Telegram when you are offline!

##
## 🚀 Features

- Send automatic replies when offline ✔️
- Block spammers who send too many messages ❌️  
- Reply with jokes, quotes to engage users 🃏
- Get notifications when someone messages you 📨
- Customize replies easily!

<br>
  
<p align="center">
  <img src="https://raw.githubusercontent.com/hk4crprasad/tgpirobot/master/IMG_20231118_231056.jpg">
</p>

<p align="center"> 
  <b>Demo of tgpirobot auto-replying on Telegram</b>
</p>

##
## 📥 Installation

```bash
pip install tgpirobot
```

```bash
git clone https://github.com/hk4crprasad/tgpirobot.git
cd tgpirobot/tgpirobot
python main.py -r
```
## Update
```bash
pip install --upgrade pirobot
```
<br>

### OR
```bash
python main.py --update
```
##
## 🤹 Usage

### Get API Credentials

- Visit [my.telegram.org](https://my.telegram.org) and login  
- Go to API Development tools
- Create a new app
- Copy `api_id` and `api_hash`

### Run the Bot

```python
Your API_ID: YOUR_API_ID
Your API_HASH: YOUR_API_HASH
Debug mode (true/false): true or false(false is good)
Handler name(Telegram/insta/github) : github
Link : https://github.com/hk4crprasad
```

Now your account will auto-reply when offline! 🎉

### Its ask for Number and Otp

<p align="center">
  <img src="https://raw.githubusercontent.com/hk4crprasad/tgpirobot/master/TGPIROBOT%20(2).png">
</p>

## Also can be used like `from tgpirobot import TgPiRobot`

<p align="center">
  
![HK4CRPRASAD](https://raw.githubusercontent.com/hk4crprasad/tgpirobot/master/You%20can%20use%20in%20your%20code%20like.svg)
</p>

##
## 🧑 Author 

Made with ❤️ by [hk4crprasad](https://github.com/hk4crprasad)

## 📄 License

[GPL-3.0](https://github.com/hk4crprasad/tgpirobot/blob/master/LICENSE)

<p align="center">
<a href="https://github.com/hk4crprasad/tgpirobot"><img src="https://raw.githubusercontent.com/hk4crprasad/hk4crprasad/master/OIG_bgremoval.ai.png"></a>
